--- old/drivers/mtd/nand/nand_base.c	2013-11-18 13:18:11.293334000 -0500
+++ new/drivers/mtd/nand/nand_base.c	2013-12-06 10:15:16.233939000 -0500
@@ -47,6 +47,8 @@
 #include <linux/bitops.h>
 #include <linux/leds.h>
 #include <asm/io.h>
+#include <linux/proc_fs.h>
+#include <linux/seq_file.h>
 
 #ifdef CONFIG_MTD_PARTITIONS
 #include <linux/mtd/partitions.h>
@@ -88,6 +90,19 @@
 static int nand_do_write_oob(struct mtd_info *mtd, loff_t to,
 			     struct mtd_oob_ops *ops);
 
+static int identnandflash_open(struct inode *inode, struct  file *file);
+
+#define MAX_FLASHNAME_LEN       128
+char nand_chipname[MAX_FLASHNAME_LEN] = {0};
+
+static const struct file_operations identnandflash_fops = {
+  .owner = THIS_MODULE,
+  .open = identnandflash_open,
+  .read = seq_read,
+  .llseek = seq_lseek,
+  .release = single_release,
+};
+
 /*
  * For devices which display every fart in the system on a separate LED. Is
  * compiled away when LED support is disabled.
@@ -2481,6 +2496,9 @@
 	       " 0x%02x, Chip ID: 0x%02x (%s %s)\n", *maf_id, dev_id,
 	       nand_manuf_ids[maf_idx].name, type->name);
 
+        snprintf(nand_chipname, MAX_FLASHNAME_LEN, "NAND device: Manufacturer ID: 0x%02x, Chip ID: 0x%02x (%s %s)\n", *maf_id, dev_id,
+	       nand_manuf_ids[maf_idx].name, type->name);
+
 	return type;
 }
 
@@ -2802,15 +2820,26 @@
 EXPORT_SYMBOL_GPL(nand_scan_tail);
 EXPORT_SYMBOL_GPL(nand_release);
 
+static int identnandflash_show(struct seq_file *m, void *v) {
+  seq_printf(m, nand_chipname);
+  return 0;
+}
+
+static int identnandflash_open(struct inode *inode, struct  file *file) {
+  return single_open(file, identnandflash_show, NULL);
+}
+
 static int __init nand_base_init(void)
 {
 	led_trigger_register_simple("nand-disk", &nand_led_trigger);
+        proc_create("nandflash", 0, NULL, &identnandflash_fops);
 	return 0;
 }
 
 static void __exit nand_base_exit(void)
 {
 	led_trigger_unregister_simple(nand_led_trigger);
+        remove_proc_entry("nandflash", NULL);
 }
 
 module_init(nand_base_init);
